Computation times — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Computation times

04:02.801 total execution time for 11 files from examples00-band_structure:

Example | Time | Mem (MB)
--- | --- | ---
Plotting 2D band structure (`plot_2d_bands.py`) | 02:44.356 | 0.0
Autobands plotting (`plot_autobands.py`) | 00:23.127 | 0.0
Plotting Inverse participation ratio (`plot_ipr.py`) | 00:21.526 | 0.0
Unfolding Band Structure (`plot_unfolding.py`) | 00:20.196 | 0.0
Plotting band structure (`plot_colinear.py`) | 00:02.830 | 0.0
Plotting with Configurations in pyprocar (`plot_bandsplot_configurations.py`) | 00:02.433 | 0.0
Plotting non colinear band structures in VASP (`plot_noncolinear_vasp.py`) | 00:02.320 | 0.0
Plotting spin polarized band structures (`plot_spin_polarized.py`) | 00:02.218 | 0.0
Plotting non colinear band structures in Quantum Espresso (`plot_noncolinear_qe.py`) | 00:01.505 | 0.0
Comparing band structures (`plot_compare_bands.py`) | 00:01.161 | 0.0
Plotting Atomic Levels (`plot_atomic_levels.py`) | 00:01.129 | 0.0